@@ -98,8 +98,74 @@ pub struct HexColor {
     pub raw: JsWord,
 }
 
-#[ast_node("Dimension")]
-pub struct Dimension {
+#[ast_node]
+pub enum Dimension {
+    #[tag("Length")]
+    Length(Length),
+
+    #[tag("Angle")]
+    Angle(Angle),
+
+    #[tag("Time")]
+    Time(Time),
+
+    #[tag("Frequency")]
+    Frequency(Frequency),
+
+    #[tag("Resolution")]
+    Resolution(Resolution),
+
+    #[tag("Flex")]
+    Flex(Flex),
+
+    #[tag("UnknownDimension")]
+    UnknownDimension(UnknownDimension),
+}
+
+#[ast_node("Length")]
+pub struct Length {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("Angle")]
+pub struct Angle {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("Time")]
+pub struct Time {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("Frequency")]
+pub struct Frequency {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("Resolution")]
+pub struct Resolution {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("Flex")]
+pub struct Flex {
+    pub span: Span,
+    pub value: Number,
+    pub unit: Ident,
+}
+
+#[ast_node("UnknownDimension")]
+pub struct UnknownDimension {
     pub span: Span,
     pub value: Number,
     pub unit: Ident,
